package db;

import java.lang.reflect.Field;
import java.lang.reflect.Type;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

public class Util {
    /**
     * 将标准时间转为Unix秒
     * @param date String格式时间
     * @return long
     * @author none
     * @date 2020-11-05 00:00
     */
    public static long dateStringToUTCSeconds(String date) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return (long) (format.parse(date).getTime() / 1000);
    }
    /**
     * 将标准时间转为Unix毫秒
     * @param date String格式时间
     * @return long
     * @author none
     * @date 2020-11-05 00:00
     */
    public static long dateStringToUTCMilliSeconds(String date) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return format.parse(date).getTime();
    }

    public static long dateStringToUTCNanoseconds(String date) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return format.parse(date).getTime()*1000000;
    }


    /**
     * 将Unix秒转为标准时间
     * @param utcSeconds long格式当前unix时间秒数
     * @return String
     * @author none
     * @date 2020-11-05 00:00
     */
    public static String uTCSecondsToDateString(long utcSeconds) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return format.format(new Date(utcSeconds * 1000));
    }

   /**
     * 将Unix秒转为标准时间
     * @param utcMilliSeconds long格式当前unix时间毫秒数
     * @return String
     * @author none
     * @date 2020-11-05 00:00
     */
    public static String uTCMilliSecondsToDateString(long utcMilliSeconds) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return format.format(new Date(utcMilliSeconds));
    }

   /**
     * 将Unix秒转为标准时间
     * @param utcMilliSeconds long格式当前unix时间毫秒数
     * @return String
     * @author none
     * @date 2020-11-05 00:00
     */
    public static String uTCMilliSecondsToDateStringWithMs(long utcMilliSeconds) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.S");
        return format.format(new Date(utcMilliSeconds));
    }

    public static String uTCMSToDateString(String utcSeconds) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        long second= Long.parseLong(utcSeconds.substring(0,10));
        return (format.format(new Date(second*1000)))+":"+utcSeconds.substring(10);
    }

    public static String UTCNanosecondsToDateString(long utcNanoseconds) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return format.format(new Date(utcNanoseconds/1000000));
    }

    /**
     * 将Unix秒转为标准时间
     * @param utcSeconds long格式当前unix时间秒数
     * @return String
     * @author none
     * @date 2020-11-05 00:00
     */
    public static String uTCSecondsToDateStringYear(long utcSeconds) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy");
        return format.format(new Date(utcSeconds * 1000));
    }

    /**
     * 将Unix秒转为标准时间
     * @param utcSeconds long格式当前unix时间秒数
     * @return String
     * @author none
     * @date 2020-11-05 00:00
     */
    public static String uTCSecondsToDateStringMonth(long utcSeconds) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("MM");
        return format.format(new Date(utcSeconds * 1000));
    }

    /**
     * 返回当前时间的Unix值，单位为毫秒
     * @return long
     * @author none
     * @date 2020-11-05 00:00
     */
    public static long currentUTCSeconds() {
        return System.currentTimeMillis() / 1000;
    }

    /**
     * 返回当前时间的Unix值，单位为毫秒
     * @return long
     * @author none
     * @date 2020-11-05 00:00
     */
    public static long currentUTCMilliSeconds() {
        return System.currentTimeMillis();
    }

    public static long currentUTCNanoseconds() {
        return System.nanoTime();
    }


    /**
     * 返回human-readable的数据尺寸大小
     * @param size
     * @return String
     * @author none
     * @date 2020-11-05 00:00
     */
    public static String getNetFileSizeDescription(long size) {
        StringBuffer bytes = new StringBuffer();
        DecimalFormat format = new DecimalFormat("###.0");
        if (size >= 1024 * 1024 * 1024) {
            double i = (size / (1024.0 * 1024.0 * 1024.0));
            bytes.append(format.format(i)).append("GB");
        } else if (size >= 1024 * 1024) {
            double i = (size / (1024.0 * 1024.0));
            bytes.append(format.format(i)).append("MB");
        } else if (size >= 1024) {
            double i = (size / (1024.0));
            bytes.append(format.format(i)).append("KB");
        } else if (size < 1024) {
            if (size <= 0) {
                bytes.append("0B");
            } else {
                bytes.append((int) size).append("B");
            }
        }
        return bytes.toString();
    }

    /// 逃逸 SQL 字符串，防止 SQL 注入
    public static String EscapeSqlName(String name) {
        return name.replace("\\", "\\\\").replace("'", "\\'");
    }

    public static String MakeSqlStrLiteral(String value) {
        return "'" + EscapeSqlName(value) + "'";
    }

    public static String ToSqlLiteral(String str) {
        return MakeSqlStrLiteral(str);
    }

    public static String ToSqlLiteral(double val) {
        return String.valueOf(val);
    }

    public static String ToSqlLiteral(int num) {
        return String.valueOf(num);
    }

    public static String ToSqlLiteral(long num) {
        return String.valueOf(num);
    }

    public static String ToSqlLiteral(Map<?, ?> mp) {
        StringBuilder sb = new StringBuilder();
        boolean isFirst = true;
        sb.append("[");
        for (Map.Entry<?, ?> entry : mp.entrySet()) {
            if (!isFirst) {
                sb.append(",");
            }
            sb.append("(");
            sb.append(ToSqlLiteral(entry.getKey().toString()));
            sb.append(",");
            sb.append(ToSqlLiteral(entry.getValue().toString()));
            sb.append(")");
            isFirst = false;
        }
        sb.append("]");
        return sb.toString();
    }

}
